SparkWorks Python Client
========================

Management Service for the SparkWorks Processing Engine

This Python package is automatically generated by the `Swagger
Codegen <https://github.com/swagger-api/swagger-codegen>`__ project:

-  API version: v2.0
-  Package version: 1.0.0
-  Build package: io.swagger.codegen.languages.PythonClientCodegen For
   more information, please visit http://www.sparkworks.net/

Requirements.
-------------

Python 2.7 and 3.4+

Installation & Usage
--------------------

pip install
~~~~~~~~~~~

If the python package is hosted on Github, you can install directly from
Github

.. code:: sh

    pip install git+https://github.com//.git

(you may need to run ``pip`` with root permission:
``sudo pip install git+https://github.com//.git``)

Then import the package:

.. code:: python

    import sparkworks_client 

Setuptools
~~~~~~~~~~

Install via `Setuptools <http://pypi.python.org/pypi/setuptools>`__.

.. code:: sh

    python setup.py install --user

(or ``sudo python setup.py install`` to install the package for all
users)

Then import the package:

.. code:: python

    import sparkworks_client

Getting Started
---------------

Please follow the `installation procedure <#installation--usage>`__ and
then run the following:

.. code:: python

    from __future__ import print_function
    import time
    import sparkworks_client
    from sparkworks_client.rest import ApiException
    from pprint import pprint

    # Configure OAuth2 access token for authorization: oauth2
    configuration = sparkworks_client.Configuration()
    configuration.access_token = 'YOUR_ACCESS_TOKEN'

    # create an instance of the API class
    api_instance = sparkworks_client.CommandAPIApi(sparkworks_client.ApiClient(configuration))
    uuid = 'uuid_example' # str | The unique identifier of the Actuator Resource
    command_dto = sparkworks_client.CommandAPIModel() # CommandAPIModel | commandDto

    try:
        # Send a command to a SparkWorks Actuator Resource
        api_response = api_instance.send_command(uuid, command_dto)
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling CommandAPIApi->send_command: %s\n" % e)

